.. _snippets:

Snippets
========

Welcome to the Eve snippet archive. This is the place where anyone can drop
helpful pieces of code for others to use.

Available Snippets
------------------

.. toctree::
   :maxdepth: 1

   hooks_blueprints
   list_of_items


Add your snippet
----------------
Want to add your snippet? Just add your own .rst file to the `snippets folder`_
(see the template below for reference), update the TOC in this page (see
source_), and then submit a `pull request`_.

.. toctree::
   :maxdepth: 2

   template

.. _template: https://raw.githubusercontent.com/pyeve/eve/master/docs/snippets/template.rst
.. _`pull request`: https://github.com/pyeve/eve/pulls
.. _`snippets folder`: https://github.com/pyeve/eve/tree/master/docs/snippets
.. _source: https://raw.githubusercontent.com/pyeve/eve/master/docs/snippets/index.rst
